<?php
/**
 * eKomi Integration.
 *
 * @category module
 * @package eKomi Integration
 * @version 2.1.1
 * @author eKomi
 * @copyright Copyright (c) eKomi GMBH (https://ekomi.de)
 * @license AFL
 */

class ControllerModuleEkomiIntegration extends Controller {
    /**
     * property named $error is defined to put errors
     * @var array
     */
    private $error = array();

    /**
     * Basic function of the controller. This can be called using route=module/ekomi_integration
     */
    public function index() {

        //Loads the language file.
        $this->load->language('module/ekomi_integration');

        //Sets the title to the html page
        $this->document->setTitle($this->language->get('heading_title'));

        //Loads the model file. Path of the file to be given
        $this->load->model('setting/setting');

        //Checks whether the request type is post. If yes, then calls the validate function.
        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {

            $this->model_setting_setting->editSetting('ekomi_integration', $this->request->post);

            $this->session->data['success'] = $this->language->get('text_success');

            $this->response->redirect($this->url->link('extension/module', 'token=' . $this->session->data['token'], true));
        }



        $data['heading_title'] = $this->language->get('heading_title');

        $data['text_edit']     = $this->language->get('text_edit');
        $data['text_enabled']  = $this->language->get('text_enabled');
        $data['text_disabled'] = $this->language->get('text_disabled');

        $data['entry_status']         = $this->language->get('entry_status');
        $data['shop_id_text']         = $this->language->get('shop_id');
        $data['shop_pw_text']         = $this->language->get('shop_pw');
        $data['api_mode_text']        = $this->language->get('api_mode');
        $data['api_mode_email']       = $this->language->get('api_mode_email');
        $data['api_mode_sms']         = $this->language->get('api_mode_sms');
        $data['api_mode_fallback']    = $this->language->get('api_mode_fallback');
        $data['product_reviews_text'] = $this->language->get('product_reviews');
        $data['order_status_text']    = $this->language->get('order_status');
        $data['order_status_help']    = $this->language->get('order_status_help');
        $data['terms_and_conditions'] = $this->language->get('terms_and_conditions');
        $data['text_agree']           = $this->language->get('text_agree');
        $data['text_disagree']        = $this->language->get('text_disagree');
        $data['terms_and_conditions_text']        = $this->language->get('terms_and_conditions_text');

        $data['button_save']   = $this->language->get('button_save');
        $data['button_cancel'] = $this->language->get('button_cancel');


        if(isset($this->error['warning'])){
            $data['error_warning'] = $this->error['warning'];
        } else {
            $data['error_warning'] = '';
        }

        $data['breadcrumbs'] = array();

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], true)
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_module'),
            'href' => $this->url->link('extension/module', 'token=' . $this->session->data['token'], true)
        );

        $data['breadcrumbs'][] = array(
        'text' => $this->language->get('heading_title'),
        'href' => $this->url->link('module/ekomi_integration', 'token=' . $this->session->data['token'], true)
        );

        if (!isset($this->request->get['module_id'])) {
            $data['action'] = $this->url->link('module/ekomi_integration', 'token=' . $this->session->data['token'], true);
        } else {
            $data['action'] = $this->url->link('module/ekomi_integration', 'token=' . $this->session->data['token'] . '&module_id=' . $this->request->get['module_id'], true);
        }

        $data['cancel'] = $this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL');

        /*
         * Setting data in configuratiopn fields
         */
        if (isset($this->request->post['ekomi_integration_shop_id'])) {
            $data['ekomi_integration_shop_id'] = $this->request->post['ekomi_integration_shop_id'];
        } else {
            $data['ekomi_integration_shop_id'] = $this->config->get('ekomi_integration_shop_id');
        }

        if (isset($this->request->post['ekomi_integration_shop_pw'])) {
            $data['ekomi_integration_shop_pw'] = $this->request->post['ekomi_integration_shop_pw'];
        } else {
            $data['ekomi_integration_shop_pw'] = $this->config->get('ekomi_integration_shop_pw');
        }

        $data['api_modes'] = array(
            'email' => $data['api_mode_email'],
            'sms'   => $data['api_mode_sms'],
            'fallback' => $data['api_mode_fallback']
        );

        if (isset($this->request->post['ekomi_integration_api_mode'])) {
            $data['ekomi_integration_api_mode'] = $this->request->post['ekomi_integration_api_mode'];
        } else {
            $data['ekomi_integration_api_mode'] = $this->config->get('ekomi_integration_api_mode');
        }

        if (isset($this->request->post['ekomi_integration_product_reviews'])) {
            $data['ekomi_integration_product_reviews'] = $this->request->post['ekomi_integration_product_reviews'];
        } else {
            $data['ekomi_integration_product_reviews'] = $this->config->get('ekomi_integration_product_reviews');
        }

        if (isset($this->request->post['ekomi_integration_status'])) {
            $data['ekomi_integration_status'] = $this->request->post['ekomi_integration_status'];
        } else {
            $data['ekomi_integration_status'] = $this->config->get('ekomi_integration_status');
        }

        if (isset($this->request->post['ekomi_integration_terms_and_conditions'])) {
            $data['ekomi_integration_terms_and_conditions'] = $this->request->post['ekomi_integration_terms_and_conditions'];
        } else {
            $data['ekomi_integration_terms_and_conditions'] = ($this->config->get('ekomi_integration_terms_and_conditions') != '') ? $this->config->get('ekomi_integration_terms_and_conditions') : 1;
        }

        $this->load->model('localisation/order_status');
        $data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

        if (isset($this->request->post['ekomi_integration_order_status'])) {
            $data['ekomi_integration_order_status'] = $this->request->post['ekomi_integration_order_status'];
        } else {
            $data['ekomi_integration_order_status'] = $this->config->get('ekomi_integration_order_status');
            if ($data['ekomi_integration_order_status'] == null) {
                $data['ekomi_integration_order_status'] = array();
            }
        }

        $data['header'] = $this->load->controller('common/header');

        $data['column_left'] = $this->load->controller('common/column_left');

        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('module/ekomi_integration.tpl', $data));

    }

    /**
     * validate function validates the values of the post and also the permission
     * @return boolean return true if any of the index of $error contains value
     */
    protected function validate()
    {
        $shopId = $this->request->post['ekomi_integration_shop_id'] = trim($this->request->post['ekomi_integration_shop_id']);
        $shopPw = $this->request->post['ekomi_integration_shop_pw'] = trim($this->request->post['ekomi_integration_shop_pw']);

        if (!$this->user->hasPermission('modify', 'module/ekomi_integration')) {
            $this->error['warning'] = $this->language->get('error_permission');
        } else if ($shopId == '' || $shopPw == '') {
            $this->error['warning'] = $this->language->get('validation_error_empty');
        } else {
            if (!$this->validateAccount($shopId, $shopPw)) {
                $this->error['warning'] = $this->language->get(
                    'validation_error'
                );
            }
        }

        return !$this->error;
    }

    /**
     * @param $shopId
     * @param $shopPw
     *
     * @return bool
     */
    protected function validateAccount($shopId, $shopPw)
    {
        $ApiUrl = 'http://api.ekomi.de/v3/getSettings';
        $ApiUrl .= "?auth={$shopId}|{$shopPw}&version=cust-1.0.0&type=request&charset=iso&app=PD-Opencart-20";

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $ApiUrl );
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $server_output = curl_exec($ch);
        curl_close($ch);

        if ($server_output == 'Access denied')
            return false;

        return true;
    }

    public function install()
    {
        // Register the event triggers
        $this->load->model('extension/event');

        $this->model_extension_event->addEvent(
            'ekomi_history_capture',
            'post.order.history.add',
            'module/ekomi_integration/order_export'
        );
    }

    public function uninstall()
    {
        // delete the event triggers
        $this->load->model('extension/event');

        $this->model_extension_event->deleteEvent('ekomi_history_capture');
    }

}